function [cAnalogUsage cLogicUsage dTime dAnalog dLogic] = Hi8860(filename, dAxis, dTop, dWidth)

%---------------------------------------------------------------------------
%
% 	Loading driver for the 'Memory HiCORDER 8860 series'.
%
%	Ver 1.01
%
%	< Definition >
%	[cAnalogUsage cLogicUsage dTime dAnalog dLogic] = Hi8860(filename, dAxis, dTop, dWidth)
%
%	Hi8860( ) is the driver used to load HIOKI MEMORY HiCORDER 8860 Series ".mem" files into MATLAB.
%
%	[Input Argument]
%		@filename
%			Specify the file name.
%			(Example:) data.mem
%
%		@dAxis	(May be omitted, required when specifying values for @dTop and beyond.)
%			Used for specifying the time axis as a value.  When omitted, single-axis will be used.
%			(Example:) 1=Single-axis , 2=Dual-axis
%
%		@dTop	(May be omitted, required when specifying a value for @dWidth.)
%			Specify the starting storage location using a point (from 0).  When omitted, storage will begin at 0.
%			(Example:) When storing from the top (first data)=0, when storing from the 101st data=100
%
%		@dWidth	(May be omitted.)
%			Specify the storage number.  When omitted, all data starting from @dTop will be stored.
%			(Example:) To store 100 data=100
%
%	[Output Argument]
%		@cAnalogUsage (char array)
%			Displays the save status of the analog channels in a 16x8 arrangement.
%			The returned values 0 or 1 represents the save status of each channel,
%			such that 1 represents saved and 0 represents not saved.
%			The returned value will represent, from the top, Unit 1, 2, 3,..., and Channels 1, 2, 3,...from the left.
%
%			(Response Example:)	1100000000000000
%								0000000000000000
%								0000000000000000
%								0000000000000000
%								0000000000000000
%								0000000000000000
%								0000000000000000
%								0000000000000000
%				CH1_1, CH1_2 = Stored
%				CH2 and beyond = Not stored (no data)
%
%		@cLogicUsage (char array)
%			Displays the save status of the logic channels.
%			The returned value 0 or 1 represents the save status of each channel,
%			such that 1 represents saved and 0 represents not saved.
%			The left-most value of the returned value represents CHA, with each subsequent value
%			to the right representing the next higher order channel.
%
%			(Response Example:)	1100
%				CHA (CHA-1) to (CHA-4) = Stored
%				CHB (CHB-1) to (CHB-4) = Stored
%				CHC and beyond = Not stored (no data)
%
%		@dTime (double array)
%			Displays the time axis data.
%
%		@dAnalog (double array)
%			Stores the data for the analog channels in sequence.
%			Data saved as @cAnalogUsage will be stored in order.
%			Channels not saved will be compressed.
%			When extracting the first data, specify dAnalog(:, 1).
%
%		@dLogic (uint8 array)
%			Stores the logic channel data in sequence.
%			Data saved as @cLogicUsage will be stored in order.
%			One logic channel is composed of 4 data.
%			As such, the sequence will be 4 times the single number representing cLogicUsage.
%			When @cLogicUsage is 1100, data from CHA-1 to CHB-4 is stored in @dLogic.
%			Channels not saved will be compressed.
%			When extracting the first data, specify dLogic(:, 1).
%
%	(Usage Example:)
%		[cAnalogUsage cLogicUsage dTime dAnalog dLogic] = Hi8860('single.mem')
%			(The waveform data for the 8860 waveform file "single.mem" will be stored in MatLab sequence.
%
%		[cAnalogUsage cLogicUsage dTime dAnalog dLogic] = Hi8860('dual.mem', 2)
%			(The dual-axis waveform data for the 8860 waveform file "dual.mem" will be stored in MatLab sequence.
%
%		[cAnalogUsage cLogicUsage dTime dAnalog dLogic] = Hi8860('part.mem', 1, 10)
%			(The 10th to the last single-axis waveform data for the 8860 waveform file "part.mem" will be stored in MatLab sequence.
%
%		[cAnalogUsage cLogicUsage dTime dAnalog dLogic] = Hi8860('part.mem', 1, 0, 10)
%			(The first to the 10th single-axis waveform data for the 8860 waveform file "part.mem" will be stored in MatLab sequence.
%
%	Hi8860( ) is the driver used to load HIOKI MEMORY HiCORDER 8860 series ".mem" files into MATLAB.
%	Compatible MEMORY HiCORDERs and limitations are indicated below.
%
%	1. Compatible MEMORY HiCORDERs
%		8860 / 8861 / 8860-50 / 8861-50(V1.03 or later)
%
%	2. Supported Function
%		MEM(MEMORY Function)
%
%	3. Supported MATLAB Version
%		MATLAB R2006b Version	7.3.0.267 (R2006b)
%
%	4. Compatible Operating Systems
%		WindowsXPsp3 or later (32bit)
%
%	5. Copyright
%		The copyright of this driver software and related documents belong to HIOKI E.E.CORPORATION.
%		Sales of this software or bundling with any other document without permission by copyright holder are prohibited.
%		Also, any modification of this software without permission by copyright holder is strictly prohibited.
%
%	6. Responsibility of Use
%		The programs provided here are all freeware.
%		HIOKI E.E. Corporation disclaims all responsibility for any losses arising out of use of the software provided herein, as well as for any programming errors or problems arising out of use of the software.
%		The software is provided on an "as is" basis, and HIOKI cannot respond to any inquiries concerning the software.
%
%---------------------------------------------------------------------------

[cAnalogUsage cLogicUsage dTime dAnalog dLogic] = Hi8860(filename, dAxis, dTop, dWidth);
